@@ -1,7 +1,8 @@
 import os
 import sys
 import unittest
-import test.test_support
+
+from support import test_support
 
 this_dir_path = os.path.abspath(os.path.dirname(__file__))
 
@@ -21,5 +22,5 @@ def get_tests():
             yield test
 
 if __name__ == "__main__":
-    test.test_support.use_resources = ['gui']
-    test.test_support.run_unittest(*get_tests())
+    test_support.use_resources = ['gui']
+    test_support.run_unittest(*get_tests())
