@@ -12,7 +12,7 @@ maintaining the widget state and invoking callbacks, all aspects
 of the widgets appearance lies at Themes.
 """
 
-__version__ = "0.3"
+__version__ = "0.3.2"
 
 __author__ = "Guilherme Polo <ggpolo@gmail.com>"
 
@@ -23,58 +23,61 @@ __all__ = ["Button", "Checkbutton", "Combobox", "Entry", "Frame", "Label",
            # Extensions
            "LabeledScale", "OptionMenu",
            # functions
-           "tclobjs_to_py"]
+           "tclobjs_to_py", "setup_master"]
 
-import Tkinter
+import sys
+if sys.version_info[0] == 2:
+    import Tkinter
+    _text = unicode
+    _basestr = basestring
+    _map = map
+    _randomkey = lambda d: d.iterkeys().next()
+else:
+    import tkinter as Tkinter
+    _text = str
+    _basestr = str
+    _randomkey = lambda d: next(iter(d.keys()))
+    def _map(func, *it):
+        return list(map(func, *it))
 
 _flatten = Tkinter._flatten
 
-# Verify if Tk is new enough to not need Tile checking
+# Verify if Tk is new enough to not need the Tile package
 _REQUIRE_TILE = True if Tkinter.TkVersion < 8.5 else False
 
-def _loadttk(loadtk):
-    # This extends the default Tkinter.Tk._loadtk method so we can be
-    # sure that ttk is available for use, or not.
-    def _wrapper(self):
-        loadtk(self)
-
-        if _REQUIRE_TILE:
-            import os
-            tilelib = os.environ.get('TILE_LIBRARY')
-            if tilelib:
-                # append custom tile path to the the list of directories that
-                # Tcl uses when attempting to resolve packages with the package
-                # command
-                self.tk.eval('global auto_path; '
-                             'lappend auto_path {%s}' % tilelib)
-            self.tk.eval('package require tile') # TclError may be raised here
-
-    return _wrapper
-
-# Store the original Tkinter.Tk._loadtk before replacing it just in case
-# someone wants to restore it.
-__loadtk__ = Tkinter.Tk._loadtk
-Tkinter.Tk._loadtk = _loadttk(Tkinter.Tk._loadtk)
+def _load_tile(master):
+    if _REQUIRE_TILE:
+        import os
+        tilelib = os.environ.get('TILE_LIBRARY')
+        if tilelib:
+            # append custom tile path to the list of directories that
+            # Tcl uses when attempting to resolve packages with the package
+            # command
+            master.tk.eval(
+                    'global auto_path; '
+                    'lappend auto_path {%s}' % tilelib)
 
+        master.tk.eval('package require tile') # TclError may be raised here
+        master._tile_loaded = True
 
 def _format_optdict(optdict, script=False, ignore=None):
     """Formats optdict to a tuple to pass it to tk.call.
-    
+
     E.g. (script=False):
       {'foreground': 'blue', 'padding': [1, 2, 3, 4]} returns:
       ('-foreground', 'blue', '-padding', '1 2 3 4')"""
     format = "%s" if not script else "{%s}"
 
     opts = []
-    for opt, value in optdict.iteritems():
+    for opt, value in optdict.items():
         if ignore and opt in ignore:
             continue
 
         if isinstance(value, (list, tuple)):
             v = []
             for val in value:
-                if isinstance(val, basestring):
-                    v.append(unicode(val) if val else '{}')
+                if isinstance(val, _basestr):
+                    v.append(_text(val) if val else '{}')
                 else:
                     v.append(str(val))
 
@@ -93,7 +96,7 @@ def _format_optdict(optdict, script=False, ignore=None):
 
 def _format_mapdict(mapdict, script=False):
     """Formats mapdict to pass it to tk.call.
-    
+
     E.g. (script=False):
       {'expand': [('active', 'selected', 'grey'), ('focus', [1, 2, 3, 4])]}
 
@@ -105,7 +108,7 @@ def _format_mapdict(mapdict, script=False):
     format = "%s" if not script else "{%s}"
 
     opts = []
-    for opt, value in mapdict.iteritems():
+    for opt, value in mapdict.items():
 
         opt_val = []
         # each value in mapdict is expected to be a sequence, where each item
@@ -222,14 +225,14 @@ def _script_from_settings(settings):
     script = []
     # a script will be generated according to settings passed, which
     # will then be evaluated by Tcl
-    for name, opts in settings.iteritems():
+    for name, opts in settings.items():
         # will format specific keys according to Tcl code
         if opts.get('configure'): # format 'configure'
-            s = ' '.join(map(unicode, _format_optdict(opts['configure'], True)))
+            s = ' '.join(map(_text, _format_optdict(opts['configure'], True)))
             script.append("ttk::style configure %s %s;" % (name, s))
 
         if opts.get('map'): # format 'map'
-            s = ' '.join(map(unicode, _format_mapdict(opts['map'], True)))
+            s = ' '.join(map(_text, _format_mapdict(opts['map'], True)))
             script.append("ttk::style map %s %s;" % (name, s))
 
         if 'layout' in opts: # format 'layout' which may be empty
@@ -245,7 +248,7 @@ def _script_from_settings(settings):
 
             # find where args end, and where kwargs start
             argc = 1 # etype was the first one
-            while argc < len(eopts) and not hasattr(eopts[argc], 'iteritems'):
+            while argc < len(eopts) and not hasattr(eopts[argc], 'items'):
                 argc += 1
 
             elemargs = eopts[1:argc]
@@ -266,7 +269,8 @@ def _dict_from_tcltuple(ttuple, cut_minus=True):
     opt_start = 1 if cut_minus else 0
 
     retdict = {}
-    for opt, val in zip(iter(ttuple[::2]), iter(ttuple[1::2])):
+    it = iter(ttuple)
+    for opt, val in zip(it, it):
         retdict[str(opt)[opt_start:]] = val
 
     return tclobjs_to_py(retdict)
@@ -285,7 +289,8 @@ def _list_from_statespec(stuple):
                 val = val.split()
             nval.append(val)
 
-    return [_flatten(spec) for spec in zip(iter(nval[::2]), iter(nval[1::2]))]
+    it = iter(nval)
+    return [_flatten(spec) for spec in zip(it, it)]
 
 def _list_from_layouttuple(ltuple):
     """Construct a list from the tuple returned by ttk::layout, this is
@@ -332,7 +337,7 @@ def _val_or_dict(options, func, *args):
 
 def _convert_stringval(value):
     """Converts a value to, hopefully, a more appropriate Python object."""
-    value = unicode(value)
+    value = _text(value)
     try:
         value = int(value)
     except (ValueError, TypeError):
@@ -343,12 +348,12 @@ def _convert_stringval(value):
 def tclobjs_to_py(adict):
     """Returns adict with its values converted from Tcl objects to Python
     objects."""
-    for opt, val in adict.iteritems():
-        if val and hasattr(val, '__len__') and not isinstance(val, basestring):
+    for opt, val in adict.items():
+        if val and hasattr(val, '__len__') and not isinstance(val, _basestr):
             if getattr(val[0], 'typename', None) == 'StateSpec':
                 val = _list_from_statespec(val)
             else:
-                val = map(_convert_stringval, val)
+                val = _map(_convert_stringval, val)
 
         elif hasattr(val, 'typename'): # some other (single) Tcl object
             val = _convert_stringval(val)
@@ -357,6 +362,22 @@ def tclobjs_to_py(adict):
 
     return adict
 
+def setup_master(master=None):
+    """If master is not None, itself is returned. If master is None,
+    the default master is returned if there is one, otherwise a new
+    master is created and returned.
+
+    If it is not allowed to use the default root and master is None,
+    RuntimeError is raised."""
+    if master is None:
+        if Tkinter._support_default_root:
+            master = Tkinter._default_root or Tkinter.Tk()
+        else:
+            raise RuntimeError(
+                    "No master specified and Tkinter is "
+                    "configured to not support default root")
+    return master
+
 
 class Style(object):
     """Manipulate style database."""
@@ -364,12 +385,11 @@ class Style(object):
     _name = "ttk::style"
 
     def __init__(self, master=None):
-        if master is None:
-            if Tkinter._support_default_root:
-                master = Tkinter._default_root or Tkinter.Tk()
-            else:
-                raise RuntimeError("No master specified and Tkinter is "
-                    "configured to not support default master")
+        master = setup_master(master)
+
+        if not getattr(master, '_tile_loaded', False):
+            # Load tile now, if needed
+            _load_tile(master)
 
         self.master = master
         self.tk = self.master.tk
@@ -471,7 +491,8 @@ class Style(object):
 
     def element_options(self, elementname):
         """Return the list of elementname's options."""
-        return self.tk.call(self._name, "element", "options", elementname)
+        return [opt.lstrip('-') for opt in
+                self.tk.call(self._name, "element", "options", elementname)]
 
 
     def theme_create(self, themename, parent=None, settings=None):
@@ -546,6 +567,10 @@ class Widget(Tkinter.Widget):
             active, disabled, focus, pressed, selected, background,
             readonly, alternate, invalid
         """
+        master = setup_master(master)
+        if not getattr(master, '_tile_loaded', False):
+            # Load tile now, if needed
+            _load_tile(master)
         Tkinter.Widget.__init__(self, master, widgetname, kw=kw)
 
 
@@ -1201,7 +1226,7 @@ class Treeview(Widget):
 
     def get_children(self, item=None):
         """Returns a tuple of children belonging to item.
-        
+
         If item is not specified, returns root children."""
         return self.tk.call(self._w, "children", item or '') or ()
 
@@ -1275,7 +1300,7 @@ class Treeview(Widget):
 
         To configure the tree column heading, call this with column = "#0" """
         cmd = kw.get('command')
-        if cmd and not isinstance(cmd, basestring):
+        if cmd and not isinstance(cmd, _basestr):
             # callback not registered yet, do it now
             kw['command'] = self.master.register(cmd, self._substitute)
 
@@ -1484,7 +1509,7 @@ class Treeview(Widget):
 class LabeledScale(Frame, object):
     """A Ttk Scale widget with a Ttk Label widget indicating its
     current value.
-    
+
     The Ttk Scale can be accessed through instance.scale, and Ttk Label
     can be accessed through instance.label"""
 
@@ -1602,8 +1627,7 @@ class OptionMenu(Menubutton):
         self._variable = variable
         self._callback = kwargs.pop('command', None)
         if kwargs:
-            raise Tkinter.TclError('unknown option -%s' % (
-                kwargs.iterkeys().next()))
+            raise Tkinter.TclError('unknown option -%s' % (_randomkey(kwargs)))
 
         self.set_menu(default, *values)
 
